@@ -8,7 +8,7 @@ __doc__ = r"""
            """
 
 import torch
-from draugr import kws_sink
+from warg import kws_sink
 from draugr.torch_utilities.system.device import global_torch_device
 from draugr.torch_utilities.sessions.model_sessions import TorchEvalSession
 
